import { HttpClient, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { L as ListTicketsOptions, a as ListTicketsResponse, G as GetTicketIdentifiers, b as GetTicketOptions, T as TicketingTicket, C as CheckInTicketsOptions, c as CheckInTicketResponse, D as DeleteTicketCheckInsOptions, d as DeleteTicketCheckInResponse, U as UpdateTicketIdentifiers, e as UpdateTicketOptions, f as UpdateTicketResponse, B as BulkUpdateTicketsOptions, g as BulkUpdateTicketsResponse, h as TicketOrderUpdatedEnvelope } from './events-v1-ticket-tickets.universal-p2W3dHH_.js';
export { A as Address, q as AddressLocation, o as AddressStreetOneOf, a0 as BaseEventMetadata, V as BulkUpdateTicketsRequest, i as ChannelType, l as CheckIn, H as CheckInTicketRequest, y as Counts, P as DeleteTicketCheckInRequest, v as FacetCounts, F as FormResponse, n as FormattedAddress, X as GetDemoTicketRequest, Y as GetDemoTicketResponse, z as GetTicketRequest, E as GetTicketResponse, m as GuestDetails, R as GuestDetailsUpdate, _ as IdentificationData, $ as IdentificationDataIdOneOf, I as InputValue, u as ListTicketsRequest, Z as MessageEnvelope, M as Money, N as OnlineConferencingLogin, O as OrderStatus, J as OrderUpdated, s as StandardDetails, k as State, p as StreetAddress, r as Subdivision, S as SubdivisionType, K as Ticket, t as TicketDetails, x as TicketFacetCounts, w as TicketFacets, j as TicketFieldset, Q as UpdateTicketRequest, W as WebhookIdentityType } from './events-v1-ticket-tickets.universal-p2W3dHH_.js';

declare function listTickets$1(httpClient: HttpClient): ListTicketsSignature;
interface ListTicketsSignature {
    /**
     * Retrieves a list of up to 100 tickets.
     *
     * <!--
     * >**Note:** This function is restricted and only runs if you elevate permissions using the [wix-auth.elevate()](https://www.wix.com/velo/reference/wix-auth/elevate) function.
     * -->
     * @param - Event IDs.
     * @param - Options for defining the returned list of tickets.
     */
    (eventId: string[], options?: ListTicketsOptions | undefined): Promise<ListTicketsResponse>;
}
declare function getTicket$1(httpClient: HttpClient): GetTicketSignature;
interface GetTicketSignature {
    /**
     * Retrieves a ticket by the unique ticket number.
     * @param - Details for the ticket to retrieve.
     * @param - Options for the returned ticket data.
     * @returns Ticket.
     */
    (identifiers: GetTicketIdentifiers, options?: GetTicketOptions | undefined): Promise<TicketingTicket>;
}
declare function checkInTickets$1(httpClient: HttpClient): CheckInTicketsSignature;
interface CheckInTicketsSignature {
    /**
     * Checks in 1 or more tickets.
     * @param - Event ID to which the ticket belongs.
     * @param - Options for tickets to check-in.
     */
    (eventId: string, options?: CheckInTicketsOptions | undefined): Promise<CheckInTicketResponse>;
}
declare function deleteTicketCheckIns$1(httpClient: HttpClient): DeleteTicketCheckInsSignature;
interface DeleteTicketCheckInsSignature {
    /**
     * Deletes check-ins for 1 or more tickets.
     * @param - Event ID to which the ticket belongs.
     * @param - Options for tickets to delete.
     */
    (eventId: string, options?: DeleteTicketCheckInsOptions | undefined): Promise<DeleteTicketCheckInResponse>;
}
declare function updateTicket$1(httpClient: HttpClient): UpdateTicketSignature;
interface UpdateTicketSignature {
    /**
     * Updates a ticket.
     * @param - Details for the ticket to update.
     * @param - Ticket details to update.
     */
    (identifiers: UpdateTicketIdentifiers, options?: UpdateTicketOptions | undefined): Promise<UpdateTicketResponse>;
}
declare function bulkUpdateTickets$1(httpClient: HttpClient): BulkUpdateTicketsSignature;
interface BulkUpdateTicketsSignature {
    /**
     * Archives multiple tickets.
     * @param - Options for updating the tickets.
     * @param - Event ID to which the ticket belongs.
     */
    (eventId: string, options?: BulkUpdateTicketsOptions | undefined): Promise<BulkUpdateTicketsResponse>;
}
declare const onTicketOrderUpdated$1: EventDefinition<TicketOrderUpdatedEnvelope, "wix.events.ticketing.events.OrderUpdated">;

declare const listTickets: MaybeContext<BuildRESTFunction<typeof listTickets$1> & typeof listTickets$1>;
declare const getTicket: MaybeContext<BuildRESTFunction<typeof getTicket$1> & typeof getTicket$1>;
declare const checkInTickets: MaybeContext<BuildRESTFunction<typeof checkInTickets$1> & typeof checkInTickets$1>;
declare const deleteTicketCheckIns: MaybeContext<BuildRESTFunction<typeof deleteTicketCheckIns$1> & typeof deleteTicketCheckIns$1>;
declare const updateTicket: MaybeContext<BuildRESTFunction<typeof updateTicket$1> & typeof updateTicket$1>;
declare const bulkUpdateTickets: MaybeContext<BuildRESTFunction<typeof bulkUpdateTickets$1> & typeof bulkUpdateTickets$1>;
/** */
declare const onTicketOrderUpdated: BuildEventDefinition<typeof onTicketOrderUpdated$1>;

export { BulkUpdateTicketsOptions, BulkUpdateTicketsResponse, CheckInTicketResponse, CheckInTicketsOptions, DeleteTicketCheckInResponse, DeleteTicketCheckInsOptions, GetTicketIdentifiers, GetTicketOptions, ListTicketsOptions, ListTicketsResponse, TicketOrderUpdatedEnvelope, TicketingTicket, UpdateTicketIdentifiers, UpdateTicketOptions, UpdateTicketResponse, bulkUpdateTickets, checkInTickets, deleteTicketCheckIns, getTicket, listTickets, onTicketOrderUpdated, updateTicket };
