import { u as ListTicketsRequest$1, a as ListTicketsResponse$1, z as GetTicketRequest$1, E as GetTicketResponse$1, H as CheckInTicketRequest$1, c as CheckInTicketResponse$1, P as DeleteTicketCheckInRequest$1, d as DeleteTicketCheckInResponse$1, Q as UpdateTicketRequest$1, f as UpdateTicketResponse$1, V as BulkUpdateTicketsRequest$1, g as BulkUpdateTicketsResponse$1 } from './events-v1-ticket-tickets.universal-pbX6XcSr.js';

interface TicketingTicket {
    /** Unique ticket number (issued automatically). */
    ticketNumber?: string;
    /** Associated order number. */
    orderNumber?: string;
    /**
     * Ticket definition ID. See the Ticket Definition API for additional information.
     * @format GUID
     */
    ticketDefinitionId?: string;
    /** Ticket name. */
    name?: string;
    /** Ticket price. */
    price?: Money;
    /**
     * Whether the ticket requires payment.
     * @readonly
     */
    free?: boolean;
    /** Event and ticket policies. */
    policy?: string;
    /**
     * *Deprecated:** Use `tickets.checkInUrl` instead.
     * @deprecated
     */
    qrCode?: string;
    /** Ticket check-in. */
    checkIn?: CheckIn;
    /** Associated order status. */
    orderStatus?: OrderStatusWithLiterals;
    /**
     * Whether the order and ticket are archived.
     * If set to `true`, they are not visible in the order list.
     */
    orderArchived?: boolean;
    /** Buyer full name. */
    orderFullName?: string;
    /** Guest full name. */
    guestFullName?: string | null;
    /** Guest personal details. */
    guestDetails?: GuestDetails;
    /** Whether ticket is visible in guest list. */
    archived?: boolean;
    /**
     * *Deprecated:** Use `tickets.ticketPdfUrl` instead.
     * @deprecated
     */
    ticketPdf?: string;
    /**
     * Ticket owner member ID.
     * @format GUID
     */
    memberId?: string | null;
    /**
     * Whether ticket was anonymized by GDPR delete.
     * Anonymized tickets no longer contain personally identifiable information (PII).
     */
    anonymized?: boolean;
    /**
     * Ticket check-in URL.
     *
     * Shown as QR code image in PDF.  <br/>
     * Format: `"https://www.wixevents.com/check-in/{ticket number},{event id}"`  <br/>
     * Example: `"https://www.wixevents.com/check-in/AAAA-AAAA-BB021,00000000-0000-0000-0000-000000000000"`
     */
    checkInUrl?: string;
    /** URL for ticket PDF download. */
    ticketPdfUrl?: string;
    /** Associated order checkout channel type. */
    channel?: ChannelTypeWithLiterals;
    /**
     * URL to download ticket in `.pkpass` format for Apple Wallet.
     * @format WEB_URL
     * @readonly
     */
    walletPassUrl?: string;
    /**
     * Whether ticket is canceled.
     * @readonly
     */
    canceled?: boolean | null;
}
interface Money {
    /**
     * *Deprecated:** Use `value` instead.
     * @format DECIMAL_VALUE
     * @deprecated
     */
    amount?: string;
    /**
     * Three-letter currency code in [ISO-4217 alphabetic](https://en.wikipedia.org/wiki/ISO_4217#Active_codes) format.
     * @format CURRENCY
     */
    currency?: string;
    /**
     * Monetary amount. Decimal string with a period as a decimal separator (e.g., 3.99). Optionally, starts with a single (-), to indicate that the amount is negative.
     * @format DECIMAL_VALUE
     */
    value?: string | null;
}
interface CheckIn {
    /** Time of check-in. */
    created?: Date | null;
}
declare enum OrderStatus {
    /** Order status is not available for this request fieldset. */
    NA_ORDER_STATUS = "NA_ORDER_STATUS",
    /** Order is confirmed, no payment is required. */
    FREE = "FREE",
    /** Order was paid, but the payment gateway suspended the payment. */
    PENDING = "PENDING",
    /** Order is paid. */
    PAID = "PAID",
    /** Order is confirmed but has be paid via offline payment. Status needs to be manually updated to `"PAID"`. */
    OFFLINE_PENDING = "OFFLINE_PENDING",
    /** Order is awaiting for payment at the cashier. */
    INITIATED = "INITIATED",
    /** Order is canceled. */
    CANCELED = "CANCELED",
    /** Order payment is declined. */
    DECLINED = "DECLINED",
    /** Order payment is authorized. */
    AUTHORIZED = "AUTHORIZED",
    /** Order payment is voided. */
    VOIDED = "VOIDED",
    /** Order is partially paid with less than the total amount. */
    PARTIALLY_PAID = "PARTIALLY_PAID"
}
/** @enumType */
type OrderStatusWithLiterals = OrderStatus | 'NA_ORDER_STATUS' | 'FREE' | 'PENDING' | 'PAID' | 'OFFLINE_PENDING' | 'INITIATED' | 'CANCELED' | 'DECLINED' | 'AUTHORIZED' | 'VOIDED' | 'PARTIALLY_PAID';
interface GuestDetails {
    /** Whether ticket belongs to assigned guest. */
    guestAssigned?: boolean;
    /** Guest first name. */
    firstName?: string | null;
    /** Guest last name. */
    lastName?: string | null;
    /**
     * Guest email.
     * @format EMAIL
     */
    email?: string | null;
    /** Full form response. */
    form?: FormResponse;
    /**
     * Contact ID associated with this guest.
     * @format GUID
     */
    contactId?: string | null;
    /**
     * Guest phone number.
     * @format PHONE
     */
    phone?: string | null;
}
interface FormResponse {
    /**
     * Input values entered when filling the form.
     * @maxSize 200
     */
    inputValues?: InputValue[];
}
interface InputValue {
    /**
     * Input field name.
     * @maxLength 100
     */
    inputName?: string;
    /**
     * Text entered into the input field.
     * @maxLength 5000
     */
    value?: string;
    /**
     * Multiple input values. For example, the array is filled if several checkboxes are ticked.
     * @maxSize 100
     * @maxLength 5000
     */
    values?: string[];
}
declare enum ChannelType {
    /** Buyer created the order via an online channel, such as a website or a mobile app. */
    ONLINE = "ONLINE",
    /** Sales person created the order and collected the money. */
    OFFLINE_POS = "OFFLINE_POS"
}
/** @enumType */
type ChannelTypeWithLiterals = ChannelType | 'ONLINE' | 'OFFLINE_POS';
interface ListTicketsRequest {
    /**
     * Event IDs.
     * @format GUID
     */
    eventId: string[];
    /** Offset. See [Pagination](https://dev.wix.com/api/rest/getting-started/pagination). */
    offset?: number;
    /**
     * Number of items to load per page. See [Pagination](https://dev.wix.com/api/rest/getting-started/pagination).
     * @max 100
     */
    limit?: number;
    /**
     * Order numbers.
     * @minLength 1
     * @maxLength 36
     * @maxSize 20
     */
    orderNumber?: string[];
    /**
     * Ticket numbers.
     * @minLength 1
     * @maxLength 36
     * @maxSize 50
     */
    ticketNumber?: string[];
    /**
     * Textual search filter - search is performed on "orderFullName", "guestFullName", and "ticketNumber".
     * @maxLength 200
     */
    searchPhrase?: string;
    /**
     * Order statuses.
     * @maxSize 20
     */
    orderStatus?: OrderStatusWithLiterals[];
    /**
     * Set of fields to return in the response. See [Fieldsets](https://dev.wix.com/api/rest/wix-events/wix-events/fieldset#wix-events_wix-events_fieldset_ticket-fieldset).
     * @maxSize 20
     */
    fieldset?: TicketFieldsetWithLiterals[];
    /**
     * Ticket states.
     * @maxSize 20
     */
    state?: StateWithLiterals[];
    /**
     * Site member IDs.
     * @format GUID
     * @maxSize 500
     */
    memberId?: string[];
    /**
     * Filter facets.
     * See [supported facets](https://dev.wix.com/api/rest/wix-events/wix-events/filter-and-sort#wix-events_wix-events_filter-and-sort_list-tickets).
     * @maxLength 100
     * @maxSize 20
     */
    facet?: string[];
    /**
     * Sort order. Defaults to "ticket_number:asc".
     * See [supported fields](https://dev.wix.com/api/rest/wix-events/wix-events/filter-and-sort#wix-events_wix-events_filter-and-sort_list-tickets).
     * @maxLength 100
     */
    sort?: string;
    /**
     * Guest contact IDs.
     * @format GUID
     * @maxSize 100
     */
    contactId?: string[];
    /**
     * Ticket definition IDs.
     * @format GUID
     * @maxSize 10
     */
    ticketDefinitionId?: string[];
    /**
     * Seat IDs.
     * @maxLength 36
     * @maxSize 50
     */
    seatId?: string[];
}
declare enum TicketFieldset {
    /** Include guest details in the ticket response. */
    GUEST_DETAILS = "GUEST_DETAILS",
    /** Include ticket details in the ticket response. */
    TICKET_DETAILS = "TICKET_DETAILS",
    /** Include individual guest form in the ticket response. */
    GUEST_FORM = "GUEST_FORM"
}
/** @enumType */
type TicketFieldsetWithLiterals = TicketFieldset | 'GUEST_DETAILS' | 'TICKET_DETAILS' | 'GUEST_FORM';
declare enum State {
    /** Returns only archived orders' tickets. */
    ORDER_ARCHIVED = "ORDER_ARCHIVED",
    /** Returns only non-archived orders' tickets. */
    ORDER_ACTIVE = "ORDER_ACTIVE",
    /** Returns only archived tickets. */
    TICKET_ARCHIVED = "TICKET_ARCHIVED",
    /** Returns only non-archived tickets. */
    TICKET_ACTIVE = "TICKET_ACTIVE",
    /** Returns only checked-in tickets. */
    CHECKED_IN = "CHECKED_IN",
    /** Returns only non-checked-in tickets. */
    NON_CHECKED_IN = "NON_CHECKED_IN",
    /** Returns only free tickets. */
    FREE = "FREE",
    /** Returns only paid tickets. */
    PAID = "PAID",
    /** Returns only member tickets. */
    MEMBER = "MEMBER"
}
/** @enumType */
type StateWithLiterals = State | 'ORDER_ARCHIVED' | 'ORDER_ACTIVE' | 'TICKET_ARCHIVED' | 'TICKET_ACTIVE' | 'CHECKED_IN' | 'NON_CHECKED_IN' | 'FREE' | 'PAID' | 'MEMBER';
interface ListTicketsResponse {
    /** Total tickets matching the given filters. */
    total?: number;
    /** Offset. */
    offset?: number;
    /**
     * Limit.
     * @max 100
     */
    limit?: number;
    /** Tickets. */
    tickets?: TicketingTicket[];
    /** Facets. */
    facets?: Record<string, FacetCounts>;
}
interface FacetCounts {
    /** Facet counts aggregated per value. */
    counts?: Record<string, number>;
}
interface GetTicketRequest {
    /**
     * Event ID.
     * @format GUID
     */
    eventId: string;
    /**
     * Unique ticket number.
     * @maxLength 36
     */
    ticketNumber: string;
    /**
     * Set of fields to return in the response. See [Fieldsets](https://dev.wix.com/api/rest/wix-events/wix-events/fieldset#wix-events_wix-events_fieldset_ticket-fieldset).
     * @maxSize 20
     */
    fieldset?: TicketFieldsetWithLiterals[];
}
interface GetTicketResponse {
    /** Ticket. */
    ticket?: TicketingTicket;
}
interface CheckInTicketRequest {
    /**
     * Event ID.
     * @format GUID
     */
    eventId: string;
    /**
     * Tickets to check-in.
     * @minLength 1
     * @maxLength 36
     * @minSize 1
     * @maxSize 100
     */
    ticketNumber?: string[];
}
interface CheckInTicketResponse {
    /** Updated tickets. */
    tickets?: TicketingTicket[];
}
interface DeleteTicketCheckInRequest {
    /**
     * Event ID.
     * @format GUID
     */
    eventId: string;
    /**
     * Tickets to delete check-ins for.
     * @minLength 1
     * @maxLength 36
     * @minSize 1
     * @maxSize 100
     */
    ticketNumber?: string[];
}
interface DeleteTicketCheckInResponse {
    /** Updated tickets. */
    tickets?: TicketingTicket[];
}
interface UpdateTicketRequest {
    /**
     * Event ID.
     * @format GUID
     */
    eventId: string;
    /**
     * Unique ticket number.
     * @minLength 1
     * @maxLength 36
     */
    ticketNumber: string;
    /**
     * Set of field paths, specifying which parts of this resource to update.
     * When `fields` is empty, the request is interpreted as a full update.
     * Behavior follows [google.protobuf.FieldMask](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#google.protobuf.FieldMask) semantics.
     */
    fields?: string[];
    /** Whether ticket is archived. */
    archived?: boolean;
    /** Assigned guest details. */
    guestDetails?: GuestDetailsUpdate;
}
interface GuestDetailsUpdate {
    /**
     * Assigned guest form.
     * To update non-assigned guest form, use [Update Order](https://dev.wix.com/api/rest/wix-events/wix-events/order/update-order).
     *
     * Does not support partial updates - entire form object will be replaced when `guestDetails.form` is masked.
     */
    form?: FormResponse;
}
interface UpdateTicketResponse {
    /** Updated ticket. */
    ticket?: TicketingTicket;
}
interface BulkUpdateTicketsRequest {
    /**
     * Event ID.
     * @format GUID
     */
    eventId: string;
    /**
     * Unique ticket numbers.
     * @minLength 1
     * @maxLength 36
     * @minSize 1
     * @maxSize 100
     */
    ticketNumber?: string[];
    /** Whether tickets are archived. */
    archived?: boolean;
}
interface BulkUpdateTicketsResponse {
    /** Updated tickets. */
    tickets?: TicketingTicket[];
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function listTickets(): __PublicMethodMetaInfo<'GET', {
    eventId: string;
}, ListTicketsRequest$1, ListTicketsRequest, ListTicketsResponse$1, ListTicketsResponse>;
declare function getTicket(): __PublicMethodMetaInfo<'GET', {
    eventId: string;
    ticketNumber: string;
}, GetTicketRequest$1, GetTicketRequest, GetTicketResponse$1, GetTicketResponse>;
declare function checkInTickets(): __PublicMethodMetaInfo<'POST', {}, CheckInTicketRequest$1, CheckInTicketRequest, CheckInTicketResponse$1, CheckInTicketResponse>;
declare function deleteTicketCheckIns(): __PublicMethodMetaInfo<'DELETE', {}, DeleteTicketCheckInRequest$1, DeleteTicketCheckInRequest, DeleteTicketCheckInResponse$1, DeleteTicketCheckInResponse>;
declare function updateTicket(): __PublicMethodMetaInfo<'PATCH', {
    eventId: string;
    ticketNumber: string;
}, UpdateTicketRequest$1, UpdateTicketRequest, UpdateTicketResponse$1, UpdateTicketResponse>;
declare function bulkUpdateTickets(): __PublicMethodMetaInfo<'PATCH', {
    eventId: string;
}, BulkUpdateTicketsRequest$1, BulkUpdateTicketsRequest, BulkUpdateTicketsResponse$1, BulkUpdateTicketsResponse>;

export { type __PublicMethodMetaInfo, bulkUpdateTickets, checkInTickets, deleteTicketCheckIns, getTicket, listTickets, updateTicket };
